@@ -394,7 +394,6 @@ impl crate::Encoder for Encoder {
         let mut encoder = Self::new(self.config);
         value.encode(&mut encoder)?;
         self.encode_constructed(tag, &encoder.output);
-
         Ok(())
     }
 
@@ -465,16 +464,6 @@ mod tests {
         );
     }
 
-    #[test]
-    fn explicit_empty_tag() {
-        use crate::types::Explicit;
-
-        assert_eq!(
-            &[0xA0, 0],
-            &*crate::ber::encode(&<Explicit<C0, _>>::new(None::<()>)).unwrap()
-        );
-    }
-
     #[test]
     fn encoding_oid() {
         fn oid_to_bytes(oid: &[u32]) -> Vec<u8> {
